@@ -11,28 +11,24 @@ module.exports = {
   },
   output: {
     path: __dirname + '/lib/',
-    publicPath: './lib',
+    publicPath: '/scriptedforms/',
     filename: '[name].js',
     chunkFilename: '[id].chunk.js'
   },
   resolve: {
     extensions: ['.ts', '.js']
   },
-  devtool: 'inline-source-map',
   module: {
     rules: [      
       {
-        test: /\.ts$/,
-        loaders: [
-          {
-            loader: 'awesome-typescript-loader',
-            options: { configFileName: 'tsconfig.json' }
-          }
-        ]
+        test: /\.ts$/, loaders: {
+          loader: 'awesome-typescript-loader',
+          options: { configFileName: 'tsconfig.json' }
+        }
       },
       { test: /\.scss$/, use: ['style-loader', 'css-loader', 'sass-loader']},
       { test: /\.css$/, use: ['style-loader', 'css-loader'] },
-      { test: /\.png$/, use: 'file-loader' }
+      { test: /\.(woff|woff2|ttf|eot)$/, use: 'file-loader' }
     ]
   },
   plugins: [
